==> rustc_1.86.0+dfsg1.orig.tar.xz: rustc-1.86.0-src/src/tools/clippy/tests/ui/match_bool.rs <==
#![deny(clippy::match_bool)]
#![allow(clippy::nonminimal_bool, clippy::eq_op)]

fn match_bool() {
    let test: bool = true;

    match test {
        //~^ ERROR: `match` on a boolean expression
        true => 0,
        false => 42,
    };

    let option = 1;
    match option == 1 {
        //~^ ERROR: `match` on a boolean expression
        true => 1,
        false => 0,
    };

    match test {
        //~^ ERROR: `match` on a boolean expression
        true => (),
        false => {
            println!("Noooo!");
        },
    };

    match test {
        //~^ ERROR: `match` on a boolean expression
        false => {
            println!("Noooo!");
        },
        _ => (),
    };

    match test && test {
        //~^ ERROR: `match` on a boolean expression
        false => {
            println!("Noooo!");
        },
        _ => (),
    };

    match test {
        //~^ ERROR: `match` on a boolean expression
        false => {
            println!("Noooo!");
        },
        true => {
            println!("Yes!");
        },
    };

    // Not linted
    match option {
        1..=10 => 1,
        11..=20 => 2,
        _ => 3,
    };

    // Don't lint
    let _ = match test {
        #[cfg(feature = "foo")]
        true if option == 5 => 10,
        true => 0,
        false => 1,
    };

    let _ = match test {
        //~^ ERROR: `match` on a boolean expression
        true if option == 5 => 10,
        _ => 1,
    };

    let _ = match test {
        //~^ ERROR: `match` on a boolean expression
        false if option == 5 => 10,
        _ => 1,
    };

    match test {
        //~^ ERROR: `match` on a boolean expression
        true if option == 5 => println!("Hello"),
        _ => (),
    };

    match test {
        //~^ ERROR: `match` on a boolean expression
        true if option == 5 => (),
        _ => println!("Hello"),
    };

    match test {
        //~^ ERROR: `match` on a boolean expression
        false if option == 5 => println!("Hello"),
        _ => (),
    };

    match test {
        //~^ ERROR: `match` on a boolean expression
        false if option == 5 => (),
        _ => println!("Hello"),
    };
}

fn main() {}

==> rustc_1.88.0+dfsg1.orig.tar.xz: rustc-1.88.0-src/src/tools/clippy/tests/ui/match_bool.rs <==
#![deny(clippy::match_bool)]
#![allow(clippy::nonminimal_bool, clippy::eq_op)]

fn match_bool() {
    let test: bool = true;

    match test {
        //~^ match_bool
        true => 0,
        false => 42,
    };

    let option = 1;
    match option == 1 {
        //~^ match_bool
        true => 1,
        false => 0,
    };

    match test {
        //~^ match_bool
        true => (),
        false => {
            println!("Noooo!");
        },
    };

    match test {
        //~^ match_bool
        false => {
            println!("Noooo!");
        },
        _ => (),
    };

    match test && test {
        //~^ match_bool
        false => {
            println!("Noooo!");
        },
        _ => (),
    };

    match test {
        //~^ match_bool
        false => {
            println!("Noooo!");
        },
        true => {
            println!("Yes!");
        },
    };

    // Not linted
    match option {
        1..=10 => 1,
        11..=20 => 2,
        _ => 3,
    };

    // Don't lint
    let _ = match test {
        #[cfg(feature = "foo")]
        true if option == 5 => 10,
        true => 0,
        false => 1,
    };

    let _ = match test {
        //~^ match_bool
        true if option == 5 => 10,
        _ => 1,
    };

    let _ = match test {
        //~^ match_bool
        false if option == 5 => 10,
        _ => 1,
    };

    match test {
        //~^ match_bool
        true if option == 5 => println!("Hello"),
        _ => (),
    };

    match test {
        //~^ match_bool
        true if option == 5 => (),
        _ => println!("Hello"),
    };

    match test {
        //~^ match_bool
        false if option == 5 => println!("Hello"),
        _ => (),
    };

    match test {
        //~^ match_bool
        false if option == 5 => (),
        _ => println!("Hello"),
    };
}

fn issue14099() {
    match true {
        //~^ match_bool
        true => 'a: {
            break 'a;
        },
        _ => (),
    }
}

fn main() {}
